@@ -73,9 +73,9 @@ REFMETHOD = 'meth'
 REFFUNCTION = 'func'
 INITPY = '__init__.py'
 # Regex expression for checking references of pattern like ":class:`~package_v1.module`"
-REF_PATTERN = ':(py:)?(func|class|meth|mod|ref|attr|exc):`~?[a-zA-Z0-9_\.<> ]*?`'
+REF_PATTERN = ':(py:)?(func|class|meth|mod|ref|attr|exc):`~?[a-zA-Z0-9_\.<> ]*(\(\))?`'
 # Regex expression for checking references of pattern like "~package_v1.subpackage.module"
-REF_PATTERN_LAST = '~(([a-zA-Z0-9_<>]*\.)*[a-zA-Z0-9_<>]*)'
+REF_PATTERN_LAST = '~([a-zA-Z0-9_<>]*\.)*[a-zA-Z0-9_<>]*(\(\))?'
 
 PROPERTY = 'property'
 
@@ -234,6 +234,12 @@ def _resolve_reference_in_module_summary(pattern, lines):
                 new_line = new_line.replace(matched_str, '<xref uid=\"{}\">{}</xref>'.format(xref, ref_name))
             # If it not a Cloud library, don't create xref for it.
             else:
+                # Carefully extract the original uid
+                if pattern == REF_PATTERN:
+                    index = matched_str.index('~') if '~' in matched_str else matched_str.index('`')
+                    ref_name = matched_str[index+1:-1]
+                else:
+                    ref_name = matched_str[1:]
                 new_line = new_line.replace(matched_str, '`{}`'.format(ref_name))
 
         new_lines.append(new_line)
@@ -797,24 +803,29 @@ def insert_children_on_class(app, _type, datam):
     insert_class = app.env.docfx_yaml_classes[datam[CLASS]]
     # Find the parent class using the module for subclasses of a class.
     parent_class = app.env.docfx_yaml_classes.get(datam[MODULE])
-    if parent_class:
-        insert_class += parent_class
+
     # Find the class which the datam belongs to
     for obj in insert_class:
         if obj['type'] != CLASS:
             continue
         # Add subclass & methods & attributes & properties to class
         if _type in [METHOD, ATTRIBUTE, PROPERTY, CLASS] and \
-                (
-                  # If obj is either method, attr or prop of a class and not self, or
-                  (obj[CLASS] == datam[CLASS] and obj != datam) or \
-                  # If datam is a subclass of another class.
-                  (_type == CLASS and obj['class'] == datam['module'])
-                ):
+          (obj[CLASS] == datam[CLASS] and obj != datam):
             obj['children'].append(datam['uid'])
             obj['references'].append(_create_reference(datam, parent=obj['uid']))
             insert_class.append(datam)
 
+    # If there is a parent class, determine if current class is a subclass.
+    if not parent_class:
+        return
+    for obj in parent_class:
+        if obj['type'] != CLASS:
+            continue
+        if _type == CLASS and obj['class'] == datam['module']:
+            # No need to add datam to the parent class.
+            obj['children'].append(datam['uid'])
+            obj['references'].append(_create_reference(datam, parent=obj['uid']))
+
 
 def insert_children_on_function(app, _type, datam):
     """
